@@ -529,7 +529,7 @@ class QACaller(CallerBase):
                self.delete_answer_list(answer_id_list)
                for insert_answer in answer_request_list:
                    insert_data = {
-                       "answer":insert_answer,
+                       "answer":insert_answer['answer'],
                        "start_time":"",
                        "end_time":"",
                        "sq_id":int(question_id),
