@@ -1,5 +1,5 @@
 import traceback
-
+import time
 import requests
 
 from ..entity.exception import BfEngineException, ErrorCode
@@ -36,6 +36,7 @@ class SkillServiceCaller(CallerBase):
     def update_remote_skill_status(self, skill_id: int, status: bool):
         try:
             response = requests.post(self.remote_skill_update_status_url.format(self.app_id, skill_id, 'true' if status else 'false'))
+            time.sleep(3)
             if self._response_failed(response):
                 msg = "log: 更新技能状态失败：原因: 接口返回异常。" + str(response.text) if response is not None else ''
                 raise BfEngineException(ErrorCode.dm_load_error, msg)
