@@ -19,4 +19,4 @@ class ChatService(Module):
         :param text: 用户问
         :return: 机器人回答
         """
-        return self.caller.call_module('remote_skill', text, online)
+        return self.caller.call_module('chat', text, online)
