@@ -5,15 +5,16 @@ from ..caller.config_manager_caller import ConfigManagerCaller
 
 
 class ConfigManager(Module):
-    def __init__(self, app_id, set, init):
+    def __init__(self, app_id, set, init, name=None):
         super().__init__(app_id, 'config', set)
         self.app_id = app_id
         self.caller = ConfigManagerCaller(self.app_id)
+        self.botname = name
         if init:
             self.init()
 
     def init(self):
-        self.caller.init_bot_config()
+        self.caller.init_bot_config(self.botname)
 
     def get_backfill_answers(self) -> list:
         """
