@@ -1,3 +1,5 @@
+from ..logger import log
+
 from .module import Module
 from ..caller.parser_caller import NERParserCaller
 
@@ -52,10 +54,14 @@ class NERParser(Module):
             self.init()
 
     def init(self):
-        self.caller.register_tde_user(self.app_id)
-        sys_parsers = {parser['parserId'].replace('@1', ''): parser['parserId'] for parser in
-                       self.caller.get_parser_library()}
-        self.sys_parser_id_map = sys_parsers
+        try:
+            self.caller.register_tde_user(self.app_id)
+            sys_parsers = {parser['parserId'].replace('@1', ''): parser['parserId'] for parser in
+                           self.caller.get_parser_library()}
+            self.sys_parser_id_map = sys_parsers
+        except Exception:
+            log.warning("ner: fail to init")
+
 
     def predict(self, sentence, parsers: list):
         """
